﻿/* PrescriptionTest.cs
 * part of zaaReloaded2
 * 
 * Copyright 2015 Daniel Kraus
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using NUnit.Framework;
using zaaReloaded2.Medication;

namespace Tests.Medication
{
    [TestFixture]
    class PrescriptionTest
    {
        [Test]
        [TestCase("Ramipril 5 mg 1-2-3", "Ramipril 5 mg", "1", "2", "3")]
        [TestCase("Ramipril 5 mg 1 -2 - 3", "Ramipril 5 mg", "1", "2", "3")]
        [TestCase("Ramipril 5 mg 1 - 2 - 3", "Ramipril 5 mg", "1", "2", "3")]
        [TestCase("Ramipril  5 mg  1 - 2 - 3", "Ramipril 5 mg", "1", "2", "3")]
        [TestCase("Ramipril 5 mg 1 1/2-2-3", "Ramipril 5 mg", "1 1/2", "2", "3")]
        [TestCase("Ramipril 5 mg 1 1/2 - 2 - 3", "Ramipril 5 mg", "1 1/2", "2", "3")]
        [TestCase("Ramipril 5 mg ½-⅓-¼", "Ramipril 5 mg", "½", "⅓", "¼")]
        public void ParseLine(string line, string drug, string morning,
            string noon, string evening)
        {
            Prescription p = Prescription.FromLine(line);
            Assert.AreEqual(drug, p.Drug, "Drug should be " + drug);
            Assert.AreEqual(morning, p.Morning, "Morning should be " + morning);
            Assert.AreEqual(noon, p.Noon, "Noon should be " + noon);
            Assert.AreEqual(evening, p.Evening, "Evening should be " + evening);
        }

        [Test]
        public void MultiplePrescriptions()
        {
            IEnumerable<Prescription> list = Prescription.ManyFromLine(
                "Ramipril 5 mg 1-0-0    Prograf 1 mg 1-0-1");
            Assert.AreEqual(2, list.Count());
            Assert.AreEqual("Ramipril 5 mg\t1-0-0", list.First().ToString());
            Assert.AreEqual("Prograf 1 mg\t1-0-1", list.Last().ToString());
        }

        [Test]
        [TestCase("Ramipril 5 mg", "1", "0", "0", "0", "Ramipril 5 mg\t1-0-0-0")]
        [TestCase("Ramipril 5 mg", "1", "0", "0", "", "Ramipril 5 mg\t1-0-0")]
        [TestCase("Ramipril 5 mg", "1", "0", "", "", "Ramipril 5 mg\t1-0")]
        [TestCase("Ramipril 5 mg", "1", "", "", "", "Ramipril 5 mg\t1")]
        [TestCase("Ramipril 5 mg", "1", "", "0", "0", "Ramipril 5 mg\t1-0-0-0")]
        [TestCase("Ramipril 5 mg", "1", "0", "", "0", "Ramipril 5 mg\t1-0-0-0")]
        [TestCase("Ramipril 5 mg", "1", "", "", "0", "Ramipril 5 mg\t1-0-0-0")]
        [TestCase("Ramipril 5 mg", "", "", "", "", "Ramipril 5 mg\t")]
        public void PrescriptionToString(string drug, string morning, string noon,
            string evening, string night, string formatted)
        {
            Prescription p = new Prescription(drug, morning, noon, evening, night);
            Assert.AreEqual(formatted, p.ToString());
        }
    }
}
